pub struct ResolvedCard {
pub kind: Option<String>,
pub index: usize,
pub fields: Vec<ResolvedField>,
pub body: Option<ResolvedField>,
}Expand description
One composable card’s resolved rows, with its authored kind (present even
for an unknown kind, which carries its fields verbatim), its document-array
index, and its body row when the kind enables a body.
Fields
kind: Option<String>index: usizefields: Vec<ResolvedField>body: Option<ResolvedField>Trait Implementations
Sourceimpl Clone for ResolvedCard
impl Clone for ResolvedCard
Sourcefn clone(&self) -> ResolvedCard
fn clone(&self) -> ResolvedCard
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ResolvedCard
impl Debug for ResolvedCard
Sourceimpl PartialEq for ResolvedCard
impl PartialEq for ResolvedCard
Sourceimpl Serialize for ResolvedCard
impl Serialize for ResolvedCard
impl StructuralPartialEq for ResolvedCard